Responsive class

Constructors

Responsive()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

deviceType() → dynamic
height(dynamic context) → dynamic
lg(dynamic context) → bool
md(dynamic context) → bool
orientation(dynamic context) → dynamic
sm(dynamic context) → bool
width(dynamic context) → dynamic
xl(dynamic context) → bool