AzButton class

Inheritance

Constructors

AzButton(dynamic widgetOrString, {Key? key})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widgetOrString → dynamic
final

Methods

alignment(Alignment alignment) → AzButton
autofocus() → AzButton
backgroundColor(Color color) → AzButton
bottomCenter() → AzButton
bottomLeft() → AzButton
bottomRight() → AzButton
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
center() → AzButton
centerLeft() → AzButton
centerRight() → AzButton
clipAntiAlias() → AzButton
clipAntiAliasWithSaveLayer() → AzButton
clipBehavior(Clip clipBehavior) → AzButton
clipHardEdge() → AzButton
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
dangerOutline() → AzButton
dangerSolid() → AzButton
dangerSolidThree() → AzButton
dangerSolidTwo() → AzButton
darkOutline() → AzButton
darkSolid() → AzButton
darkSolidThree() → AzButton
darkSolidTwo() → AzButton
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
elevation(double elevation) → AzButton
fixedSize(Size size) → AzButton
focusNode(FocusNode focusNode) → AzButton
foregroundColor(Color color) → AzButton
height(double height) → AzButton
heightFull() → AzButton
iconColor(Color color) → AzButton
iconSize(double double) → AzButton
infoOutline() → AzButton
infoSolid() → AzButton
infoSolidThree() → AzButton
infoSolidTwo() → AzButton
lightOutline() → AzButton
lightSolid() → AzButton
lightSolidThree() → AzButton
lightSolidTwo() → AzButton
maxHeight(double height) → AzButton
maximumSize(Size size) → AzButton
maxWidth(double width) → AzButton
minHeight(double height) → AzButton
minimumSize(Size size) → AzButton
minWidth(double width) → AzButton
mousecursor(MouseCursor? MouseCursor) → AzButton
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFocusChange(void callback(bool)?) → AzButton
onHover(void callback(bool)?) → AzButton
onLongPress(VoidCallback? callback) → AzButton
onPressed(VoidCallback? callback) → AzButton
outline() → AzButton
overlayColor(Color color) → AzButton
p(double padding) → AzButton
pLTRB(dynamic left, dynamic top, dynamic right, dynamic bottom) → AzButton
pOnly({double left = 0, double top = 0, double right = 0, double bottom = 0}) → AzButton
primaryOutline() → AzButton
primarySolid() → AzButton
primarySolidThree() → AzButton
primarySolidTwo() → AzButton
pSymmetric({required double h, required double v}) → AzButton
px({required double x}) → AzButton
py({required double y}) → AzButton
radius(double double) → AzButton
radiusBottom(double double) → AzButton
radiusBottomLeftTopRight(double double) → AzButton
radiusCircle() → AzButton
radiusLeft(double double) → AzButton
radiusPosition(double topLeft, double topRight, double bottomRight, double bottomLeft) → AzButton
radiusRight(double double) → AzButton
radiusTop(double double) → AzButton
radiusTopLeftBottomRight(double double) → AzButton
secondaryOutline() → AzButton
secondarySolid() → AzButton
secondarySolidThree() → AzButton
secondarySolidTwo() → AzButton
shadowColor(Color color) → AzButton
side(BorderSide borderSide) → AzButton
solidThree(dynamic color, dynamic colorOverlay) → AzButton
solidTwo(dynamic color, dynamic colorOverlay, dynamic borderWidth) → AzButton
successOutline() → AzButton
successSolid() → AzButton
successSolidThree() → AzButton
successSolidTwo() → AzButton
surfaceTintColor(Color color) → AzButton
toBuild() → dynamic
toCard() → AzCard
toCenter() → AzCenter
toContainer() → AzContainer
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGestureDetector() → AzGestureDetector
toInkWell() → AzInkWell
topCenter() → AzButton
topLeft() → AzButton
toPositioned() → AzPositioned
topRight() → AzButton
toResponsive() → AzResponsive
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
warningOutline() → AzButton
warningSolid() → AzButton
warningSolidThree() → AzButton
warningSolidTwo() → AzButton
wFull() → AzButton
width(double width) → AzButton

Operators

operator ==(Object other) → bool
The equality operator.
inherited