AzCard class

Inheritance

Constructors

AzCard(Widget? child, {Key? key})

Properties

child → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

borderOnForeground(bool borderOnForeground) → AzCard
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
clipBehavior(Clip clipBehavior) → AzCard
color(String hexCode) → AzCard
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
elevation(double elevation) → AzCard
internalUseOfAz({dynamic color, dynamic shadowColor, dynamic elevation, dynamic shape, dynamic borderOnForeground, dynamic margin, dynamic clipBehavior, dynamic semanticContainer}) → AzCard
margin(EdgeInsetsGeometry margin) → AzCard
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
semanticContainer(bool semanticContainer) → AzCard
shadowColor(String hexCode) → AzCard
shape(ShapeBorder shape) → AzCard
toBuild() → dynamic
toCenter() → AzCenter
toContainer() → AzContainer
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGestureDetector() → AzGestureDetector
toInkWell() → AzInkWell
toPositioned() → AzPositioned
toResponsive() → AzResponsive
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited