AzContainer class

Inheritance

Constructors

AzContainer({Widget widget = const SizedBox.shrink(), Key? key})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget ↔ Widget
getter/setter pair

Methods

alignment(Alignment alignment) → AzContainer
alignmentBottomCenter() → AzContainer
alignmentBottomLeft() → AzContainer
alignmentBottomRight() → AzContainer
alignmentCenter() → AzContainer
alignmentTopCenter() → AzContainer
alignmentTopLeft() → AzContainer
alignmentTopRight() → AzContainer
alignmentX(dynamic x) → AzContainer
alignmentXY(dynamic x, dynamic y) → AzContainer
alignmentY(dynamic y) → AzContainer
backgroundBlendMode(BlendMode blendMode) → dynamic
backgroundBlendModeForeground(BlendMode blendMode) → dynamic
bg(Color color) → AzContainer
bgForeground(Color color) → AzContainer
border(Color color, double width, BorderStyle style, double strokeAlign) → AzContainer
borderColor(Color color) → AzContainer
borderColorForeground(Color color) → AzContainer
borderForeground(Color color, double width, BorderStyle style, double strokeAlign) → AzContainer
borderFromLTRB(bool left, bool top, bool right, bool bottom) → AzContainer
borderFromLTRBForeground(bool left, bool top, bool right, bool bottom) → AzContainer
borderSet() → Border
borderSetForeground() → Border
borderSideSet() → BorderSide
borderSideSetForeground() → BorderSide
borderStrokeAlign(double strokeAlign) → AzContainer
borderStrokeAlignForeground(double strokeAlign) → AzContainer
borderStyle(BorderStyle borderStyle) → AzContainer
borderStyleForeground(BorderStyle borderStyle) → AzContainer
borderWidth(double width) → AzContainer
borderWidthForeground(double width) → AzContainer
boxShadow(List<BoxShadow> boxShadow) → dynamic
boxShadowForeground(List<BoxShadow> boxShadow) → dynamic
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
cardV1(Color backgroundColor) → AzContainer
clipBehavior(Clip clipBehavior) → AzContainer
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
dangerBorder() → AzContainer
dangerCard() → AzContainer
dangerSolidThree() → AzContainer
dangerSolidTwo() → AzContainer
darkBorder() → AzContainer
darkCard() → AzContainer
darkSolidThree() → AzContainer
darkSolidTwo() → AzContainer
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
decorationAssetsImage(dynamic image) → dynamic
decorationAssetsImageForeground(dynamic image) → dynamic
decorationImage(dynamic decorationImage) → dynamic
decorationImageForeground(dynamic decorationImage) → dynamic
decorationNetworkImage(dynamic image, dynamic scale) → dynamic
decorationNetworkImageForeground(dynamic image, dynamic scale) → dynamic
funBorderRadius() → BorderRadius
funBoxShadow() → BoxShadow
gradient(Gradient gradient) → dynamic
gradientForeground(Gradient gradient) → dynamic
height(double height) → AzContainer
infoBorder() → AzContainer
infoCard() → AzContainer
infoSolidThree() → AzContainer
infoSolidTwo() → AzContainer
internalUseOfAz({dynamic thisStyle, dynamic alignment, dynamic padding, dynamic color, dynamic decoration, Decoration? foregroundDecoration, dynamic width, dynamic height, dynamic constraints, dynamic margin, dynamic transform, dynamic transformAlignment, dynamic clipBehavior}) → AzContainer
lightBorder() → AzContainer
lightCard() → AzContainer
lightSolidThree() → AzContainer
lightSolidTwo() → AzContainer
m(double margin) → AzContainer
maxHeight(dynamic maxHeight) → AzContainer
maxWidth(dynamic maxWidth) → AzContainer
mb(double double) → AzContainer
minHeight(dynamic minHeight) → AzContainer
minWidth(dynamic minWidth) → AzContainer
ml(double double) → AzContainer
mLTRB(dynamic left, dynamic top, dynamic right, dynamic bottom) → AzContainer
mOnly({double left = 0, double top = 0, double right = 0, double bottom = 0}) → AzContainer
mr(double double) → AzContainer
mSymmetric({required double h, required double v}) → AzContainer
mt(double double) → AzContainer
mx(double x) → AzContainer
my(double y) → AzContainer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
p(double padding) → AzContainer
pb(double double) → AzContainer
pl(double double) → AzContainer
pLTRB(dynamic left, dynamic top, dynamic right, dynamic bottom) → AzContainer
pOnly({double left = 0, double top = 0, double right = 0, double bottom = 0}) → AzContainer
pr(double double) → AzContainer
primaryBorder() → AzContainer
primaryCard() → AzContainer
primarySolidThree() → AzContainer
primarySolidTwo() → AzContainer
pSymmetric({required double h, required double v}) → AzContainer
pt(double double) → AzContainer
px(double x) → AzContainer
py(double y) → AzContainer
radius(double radius) → AzContainer
radiusBottom(double double) → AzContainer
radiusBottomLeftTopRight(double double) → AzContainer
radiusCircle(double double) → AzContainer
radiusForeground(double radius) → AzContainer
radiusLeft(double double) → AzContainer
radiusPosition(double topLeft, double topRight, double bottomRight, double bottomLeft) → AzContainer
radiusRight(double double) → AzContainer
radiusTop(double double) → AzContainer
radiusTopLeftBottomRight(double double) → AzContainer
secondaryBorder() → AzContainer
secondaryCard() → AzContainer
secondarySolidThree() → AzContainer
secondarySolidTwo() → AzContainer
shape(BoxShape shape) → dynamic
shapeCircle() → dynamic
shapeCircleForeground() → dynamic
shapeForeground(BoxShape shape) → dynamic
solidThree(dynamic color) → AzContainer
solidTwo(dynamic borderColor, dynamic borderWidth) → AzContainer
successBorder() → AzContainer
successCard() → AzContainer
successSolidThree() → AzContainer
successSolidTwo() → AzContainer
toBuild() → dynamic
toCard() → AzCard
toCenter() → AzCenter
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGestureDetector() → AzGestureDetector
toInkWell() → AzInkWell
toPositioned() → AzPositioned
toResponsive() → AzResponsive
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
transform(Matrix4 matrix4) → AzContainer
transformAlignment(dynamic transformAlignment) → AzContainer
warningBorder() → AzContainer
warningSolidThree() → AzContainer
warningSolidTwo() → AzContainer
wFull() → AzContainer
width(double width) → AzContainer

Operators

operator ==(Object other) → bool
The equality operator.
inherited