AzImage class

Inheritance

Constructors

AzImage({Key? key})

Properties

data ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asset(String data) → AzImage
bottomCenter() → AzImage
bottomLeft() → AzImage
bottomRight() → AzImage
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
center() → AzImage
centerLeft() → AzImage
centerRight() → AzImage
color(Color color) → AzImage
contain() → AzImage
cover() → AzImage
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
errorBuilder(Widget errorBuilder(BuildContext, Object, StackTrace?)?) → AzImage
fill() → AzImage
fit(BoxFit boxFit) → AzImage
fitHeight() → AzImage
fitWidth() → AzImage
frameBuilder(Widget frameBuilder(BuildContext, Widget, int?, bool)?) → AzImage
h(double double) → AzImage
loadingBuilder(Widget loadingBuilder(BuildContext, Object, ImageChunkEvent?)?) → AzImage
network(String data) → AzImage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reapeat() → AzImage
reapeatX() → AzImage
reapeatY() → AzImage
scale(double double) → AzImage
scaleDown() → AzImage
toBuild() → dynamic
toCard() → AzCard
toCenter() → AzCenter
toContainer() → AzContainer
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGestureDetector() → AzGestureDetector
toInkWell() → AzInkWell
topCenter() → AzImage
topLeft() → AzImage
toPositioned() → AzPositioned
topRight() → AzImage
toResponsive() → AzResponsive
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
w(double double) → AzImage

Operators

operator ==(Object other) → bool
The equality operator.
inherited