AzInkWell class

Inheritance

Constructors

AzInkWell(Widget? child, {Key? key})

Properties

child ↔ Widget?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

autofocus(bool bool) → AzInkWell
borderRadius(double double) → AzInkWell
borderRadiusBottom(double double) → AzInkWell
borderRadiusBottomLeftTopRight(double double) → AzInkWell
borderRadiusCircle(double double) → AzInkWell
borderRadiusLeft(double double) → AzInkWell
borderRadiusRight(double double) → AzInkWell
borderRadiusTop(double double) → AzInkWell
borderRadiusTopLeftBottomRight(double double) → AzInkWell
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
canRequestFocus(bool bool) → AzInkWell
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
enableFeedback(bool bool) → AzInkWell
excludeFromSemantics(bool bool) → AzInkWell
focusColor(Color color) → AzInkWell
highlightColor(Color color) → AzInkWell
hoverColor(Color color) → AzInkWell
internalUseOfAz({dynamic thisOnTap, dynamic thisBorderRadius}) → AzInkWell
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSecondaryTap(VoidCallback? callback) → AzInkWell
onTap(VoidCallback? callback) → AzInkWell
onTapCancel(VoidCallback? callback) → AzInkWell
onTapDown(void callback(TapDownDetails)?) → AzInkWell
onTapUp(void callback(TapUpDetails)?) → AzInkWell
radius(double double) → AzInkWell
splashColor(Color color) → AzInkWell
toBuild() → dynamic
toCard() → AzCard
toCenter() → AzCenter
toContainer() → AzContainer
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGestureDetector() → AzGestureDetector
toPositioned() → AzPositioned
toResponsive() → AzResponsive
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited