AzNavigate class

Constructors

AzNavigate(BuildContext context)

Properties

context ↔ BuildContext
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

animationBuilder(dynamic _, dynamic a, dynamic __, dynamic c) → Widget
back() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
to({dynamic screen, dynamic duration = const Duration(seconds: 1), dynamic direction = 'no'}) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited