AzRadioListTile class

Inheritance

Constructors

AzRadioListTile({Key? key})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activeColor(String hexColor_) → AzRadioListTile
autofocus([bool autofocus = false]) → AzRadioListTile
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
contentPadding(EdgeInsetsGeometry contentPadding) → AzRadioListTile
controlAffinity(ListTileControlAffinity controlAffinity) → AzRadioListTile
controlAffinityLeading() → AzRadioListTile
controlAffinityPlatform() → AzRadioListTile
controlAffinityTrailing() → AzRadioListTile
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dense(bool dense) → AzRadioListTile
groupValue(dynamic groupValue) → AzRadioListTile
isThreeLine([bool isThreeLine = false]) → AzRadioListTile
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChanged(dynamic onChanged) → AzRadioListTile
secondary(Widget secondary) → AzRadioListTile
selected([bool selected = false]) → AzRadioListTile
selectedTileColor(String hexCode) → AzRadioListTile
shape(ShapeBorder shape) → AzRadioListTile
subtitle(Widget subtitle) → AzRadioListTile
tileColor(String hexCode) → AzRadioListTile
title(Widget title) → AzRadioListTile
toBuild() → dynamic
toCard() → AzCard
toCenter() → AzCenter
toContainer() → AzContainer
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGestureDetector() → AzGestureDetector
toggleable([bool toggleable = false]) → AzRadioListTile
toInkWell() → AzInkWell
toPositioned() → AzPositioned
toResponsive() → AzResponsive
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
value(dynamic value) → AzRadioListTile

Operators

operator ==(Object other) → bool
The equality operator.
inherited