AzRow class

Inheritance

Constructors

AzRow(List<Widget> children, {Key? key})

Properties

children ↔ List<Widget>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

alphabetic() → AzRow
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
crossCenter() → AzRow
crossEnd() → AzRow
crossStart() → AzRow
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
ideographic() → AzRow
internalUseOfAz({dynamic thisMainAxisAlignment, dynamic thisCrossAxisAlignment, dynamic thisTextDirection, dynamic thisVerticalDirection, dynamic thisTextBaseline}) → AzRow
ltr() → AzRow
mainCenter() → AzRow
mainEnd() → AzRow
mainSizeMax() → AzRow
mainSizeMin() → AzRow
mainStart() → AzRow
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rtl() → AzRow
textBaseline(TextBaseline textBaseline) → AzRow
textDirection(TextDirection textDirection) → AzRow
toBuild() → dynamic
toCard() → AzCard
toCenter() → AzCenter
toContainer() → AzContainer
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGestureDetector() → AzGestureDetector
toInkWell() → AzInkWell
toPositioned() → AzPositioned
toResponsive() → AzResponsive
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
verticalDirection(VerticalDirection verticalDirection) → AzRow
verticalDirectionDown() → AzRow
verticalDirectionUp() → AzRow

Operators

operator ==(Object other) → bool
The equality operator.
inherited