AzText class

Inheritance

Constructors

AzText(dynamic name, {Key? key})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
name ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strutStyle ↔ StrutStyle?
getter/setter pair
style ↔ TextStyle
getter/setter pair
widget ↔ Widget
getter/setter pair

Methods

alphabetic() → AzText
background(Paint background) → AzText
bold() → AzText
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
color(Color color) → AzText
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
dangerColor() → AzText
darkColor() → AzText
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
decorationColor(Color color) → AzText
decorationLineThrough() → AzText
decorationNone() → AzText
decorationOverline() → AzText
decorationStyleDashed() → AzText
decorationStyleDotted() → AzText
decorationStyleDouble() → AzText
decorationStyleSolid() → AzText
decorationStyleWavy() → AzText
decorationThickness(double decorationThickness) → AzText
decorationUnderline() → AzText
defaultColor() → AzText
fontFamily(String? fontFamily) → AzText
fontFamilyFallback(List<String> fontFamilyFallback) → AzText
fontFamilyFallbackStrut(List<String> fontFamilyFallbackStrut) → AzText
fontFamilyStrut(String fontFamilyStrut) → AzText
fontFeatures(List<FontFeature> fontFeatures) → AzText
fontSizeStrut(double fontSizeStrut) → AzText
fontStyle(FontStyle fontStyle) → AzText
fontVariations(List<FontVariation> fontVariations) → AzText
fontWeightStrut(FontWeight fontWeightStrut) → AzText
forceStrutHeight(bool forceStrutHeight) → AzText
foreground(Paint foreground) → AzText
fs(dynamic size) → AzText
fw(FontWeight fontWeight) → AzText
height(double height) → AzText
heightStrut(double heightStrut) → AzText
ideographic() → AzText
infoColor() → AzText
inherit(bool bool) → AzText
internalUseOfAz({dynamic thisStyle, dynamic thisStrutStyle, dynamic thisTextAlign, dynamic thisTextDirection, dynamic thisLocale, dynamic thisSoftWrap, dynamic thisOverflow, dynamic thisTextScaler, dynamic thisMaxLines, dynamic thisSemanticsLabel, dynamic thisTextWidthBasis, dynamic thisTextHeightBehavior, dynamic thisSelectionColor}) → AzText
leading(double leading) → AzText
leadingDistributionEven() → AzText
leadingDistributionProportional() → AzText
leadingDistributionStrut(TextLeadingDistribution? leadingDistributionStrut) → AzText
letterSpacing(double letterSpacing) → AzText
lightColor() → AzText
locale(Locale locale) → AzText
maxLines(int maxLines) → AzText
normal() → AzText
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
opacity(double double) → AzText
overflowClip() → AzText
overflowEllipsis() → AzText
overflowFade() → AzText
overflowVisible() → AzText
package(String package) → AzText
packageStrut(String packageStrut) → AzText
primaryColor() → AzText
secondaryColor() → AzText
selectionColor(Color selectionColor) → AzText
semanticsLabel(String semanticsLabel) → AzText
shadows(List<Shadow> shadows) → AzText
softWrap(bool softWrap) → AzText
successColor() → AzText
textAlign(TextAlign textAlign) → AzText
textDirection(TextDirection textDirection) → AzText
textHeightBehavior(TextHeightBehavior textHeightBehavior) → AzText
textScaler(double textScaler) → AzText
textWidthBasis(TextWidthBasis textWidthBasis) → AzText
toBuild() → dynamic
toCard() → AzCard
toCenter() → AzCenter
toContainer() → AzContainer
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGestureDetector() → AzGestureDetector
toInkWell() → AzInkWell
toPositioned() → AzPositioned
toResponsive() → AzResponsive
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
w100() → AzText
w200() → AzText
w300() → AzText
w400() → AzText
w500() → AzText
w600() → AzText
w700() → AzText
w800() → AzText
w900() → AzText
warningColor() → AzText
wordSpacing(double wordSpacing) → AzText

Operators

operator ==(Object other) → bool
The equality operator.
inherited