AzWrap class

Inheritance

Constructors

AzWrap(List<Widget> children, {Key? key})

Properties

children → List<Widget>
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

axis(Axis direction) → AzWrap
axisHorizontal() → AzWrap
axisVertical() → AzWrap
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
clipAntiAlias() → AzWrap
clipAntiAliasWithSaveLayer() → AzWrap
clipBehavior(Clip clip) → AzWrap
clipHardEdge() → AzWrap
clipNone() → AzWrap
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
crossAxisAlignment(WrapCrossAlignment wrapCrossAlignment) → AzWrap
crossCenter() → AzWrap
crossEnd() → AzWrap
crossStart() → AzWrap
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
down() → AzWrap
ltr() → AzWrap
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rtl() → AzWrap
runAlignment(WrapAlignment wrapAlignment) → AzWrap
runAlignmentBetween() → AzWrap
runAlignmentCenter() → AzWrap
runAlignmentEnd() → AzWrap
runAlignmentSpaceAround() → AzWrap
runAlignmentSpaceEvenly() → AzWrap
runAlignmentStart() → AzWrap
runSpacing(double double) → AzWrap
spacing(double double) → AzWrap
textDirection(TextDirection textDirection) → AzWrap
toBuild() → dynamic
toCard() → AzCard
toCenter() → AzCenter
toContainer() → AzContainer
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGestureDetector() → AzGestureDetector
toInkWell() → AzInkWell
toPositioned() → AzPositioned
toResponsive() → AzResponsive
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
up() → AzWrap
verticalDirection(VerticalDirection verticalDirection) → AzWrap
wrapAlignment(WrapAlignment wrapAlignment) → AzWrap
wrapAlignmentCenter() → AzWrap
wrapAlignmentEnd() → AzWrap
wrapAlignmentSpaceAround() → AzWrap
wrapAlignmentSpaceBetween() → AzWrap
wrapAlignmentSpaceEvenly() → AzWrap
wrapAlignmentStart() → AzWrap

Operators

operator ==(Object other) → bool
The equality operator.
inherited